git-branch-selector
~~~~~~~~~~~~~~~~~~~

.. image:: ./media/screenshot.png

Install
-------
::

  pip install git-branch-selector

or

::

  python3 -m pip install git-branch-selector

Usage
-----

::

  git-branch-selector


- arrow-up / down / j / k to move cursor
- enter to select branch
- q to quit
- ctrl-c to quit
